# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.talent_v4beta1.proto import (
    job_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2,
)
from google.cloud.talent_v4beta1.proto import (
    job_service_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class JobServiceStub(object):
    """A service handles job management, including job CRUD, enumeration and search.
  """

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.CreateJob = channel.unary_unary(
            "/google.cloud.talent.v4beta1.JobService/CreateJob",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.CreateJobRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2.Job.FromString,
        )
        self.BatchCreateJobs = channel.unary_unary(
            "/google.cloud.talent.v4beta1.JobService/BatchCreateJobs",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.BatchCreateJobsRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
        self.GetJob = channel.unary_unary(
            "/google.cloud.talent.v4beta1.JobService/GetJob",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.GetJobRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2.Job.FromString,
        )
        self.UpdateJob = channel.unary_unary(
            "/google.cloud.talent.v4beta1.JobService/UpdateJob",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.UpdateJobRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2.Job.FromString,
        )
        self.BatchUpdateJobs = channel.unary_unary(
            "/google.cloud.talent.v4beta1.JobService/BatchUpdateJobs",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.BatchUpdateJobsRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
        self.DeleteJob = channel.unary_unary(
            "/google.cloud.talent.v4beta1.JobService/DeleteJob",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.DeleteJobRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.BatchDeleteJobs = channel.unary_unary(
            "/google.cloud.talent.v4beta1.JobService/BatchDeleteJobs",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.BatchDeleteJobsRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.ListJobs = channel.unary_unary(
            "/google.cloud.talent.v4beta1.JobService/ListJobs",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.ListJobsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.ListJobsResponse.FromString,
        )
        self.SearchJobs = channel.unary_unary(
            "/google.cloud.talent.v4beta1.JobService/SearchJobs",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.SearchJobsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.SearchJobsResponse.FromString,
        )
        self.SearchJobsForAlert = channel.unary_unary(
            "/google.cloud.talent.v4beta1.JobService/SearchJobsForAlert",
            request_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.SearchJobsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.SearchJobsResponse.FromString,
        )


class JobServiceServicer(object):
    """A service handles job management, including job CRUD, enumeration and search.
  """

    def CreateJob(self, request, context):
        """Creates a new job.

    Typically, the job becomes searchable within 10 seconds, but it may take
    up to 5 minutes.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def BatchCreateJobs(self, request, context):
        """Begins executing a batch create jobs operation.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetJob(self, request, context):
        """Retrieves the specified job, whose status is OPEN or recently EXPIRED
    within the last 90 days.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateJob(self, request, context):
        """Updates specified job.

    Typically, updated contents become visible in search results within 10
    seconds, but it may take up to 5 minutes.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def BatchUpdateJobs(self, request, context):
        """Begins executing a batch update jobs operation.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteJob(self, request, context):
        """Deletes the specified job.

    Typically, the job becomes unsearchable within 10 seconds, but it may take
    up to 5 minutes.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def BatchDeleteJobs(self, request, context):
        """Deletes a list of [Job][google.cloud.talent.v4beta1.Job]s by filter.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListJobs(self, request, context):
        """Lists jobs by filter.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SearchJobs(self, request, context):
        """Searches for jobs using the provided [SearchJobsRequest][google.cloud.talent.v4beta1.SearchJobsRequest].

    This call constrains the [visibility][google.cloud.talent.v4beta1.Job.visibility] of jobs
    present in the database, and only returns jobs that the caller has
    permission to search against.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SearchJobsForAlert(self, request, context):
        """Searches for jobs using the provided [SearchJobsRequest][google.cloud.talent.v4beta1.SearchJobsRequest].

    This API call is intended for the use case of targeting passive job
    seekers (for example, job seekers who have signed up to receive email
    alerts about potential job opportunities), and has different algorithmic
    adjustments that are targeted to passive job seekers.

    This call constrains the [visibility][google.cloud.talent.v4beta1.Job.visibility] of jobs
    present in the database, and only returns jobs the caller has
    permission to search against.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_JobServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CreateJob": grpc.unary_unary_rpc_method_handler(
            servicer.CreateJob,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.CreateJobRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2.Job.SerializeToString,
        ),
        "BatchCreateJobs": grpc.unary_unary_rpc_method_handler(
            servicer.BatchCreateJobs,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.BatchCreateJobsRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
        "GetJob": grpc.unary_unary_rpc_method_handler(
            servicer.GetJob,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.GetJobRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2.Job.SerializeToString,
        ),
        "UpdateJob": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateJob,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.UpdateJobRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2.Job.SerializeToString,
        ),
        "BatchUpdateJobs": grpc.unary_unary_rpc_method_handler(
            servicer.BatchUpdateJobs,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.BatchUpdateJobsRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
        "DeleteJob": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteJob,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.DeleteJobRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "BatchDeleteJobs": grpc.unary_unary_rpc_method_handler(
            servicer.BatchDeleteJobs,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.BatchDeleteJobsRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "ListJobs": grpc.unary_unary_rpc_method_handler(
            servicer.ListJobs,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.ListJobsRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.ListJobsResponse.SerializeToString,
        ),
        "SearchJobs": grpc.unary_unary_rpc_method_handler(
            servicer.SearchJobs,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.SearchJobsRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.SearchJobsResponse.SerializeToString,
        ),
        "SearchJobsForAlert": grpc.unary_unary_rpc_method_handler(
            servicer.SearchJobsForAlert,
            request_deserializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.SearchJobsRequest.FromString,
            response_serializer=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__service__pb2.SearchJobsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.talent.v4beta1.JobService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from __future__ import absolute_import
import sys

from google.api_core.protobuf_helpers import get_messages

from google.cloud.talent_v4beta1.proto import application_pb2
from google.cloud.talent_v4beta1.proto import application_service_pb2
from google.cloud.talent_v4beta1.proto import common_pb2
from google.cloud.talent_v4beta1.proto import company_pb2
from google.cloud.talent_v4beta1.proto import company_service_pb2
from google.cloud.talent_v4beta1.proto import completion_service_pb2
from google.cloud.talent_v4beta1.proto import event_pb2
from google.cloud.talent_v4beta1.proto import event_service_pb2
from google.cloud.talent_v4beta1.proto import filters_pb2
from google.cloud.talent_v4beta1.proto import histogram_pb2
from google.cloud.talent_v4beta1.proto import job_pb2
from google.cloud.talent_v4beta1.proto import job_service_pb2
from google.cloud.talent_v4beta1.proto import profile_pb2
from google.cloud.talent_v4beta1.proto import profile_service_pb2
from google.cloud.talent_v4beta1.proto import tenant_pb2
from google.cloud.talent_v4beta1.proto import tenant_service_pb2
from google.longrunning import operations_pb2
from google.protobuf import any_pb2
from google.protobuf import duration_pb2
from google.protobuf import empty_pb2
from google.protobuf import field_mask_pb2
from google.protobuf import timestamp_pb2
from google.protobuf import wrappers_pb2
from google.rpc import status_pb2
from google.type import date_pb2
from google.type import latlng_pb2
from google.type import money_pb2
from google.type import postal_address_pb2
from google.type import timeofday_pb2


_shared_modules = [
    operations_pb2,
    any_pb2,
    duration_pb2,
    empty_pb2,
    field_mask_pb2,
    timestamp_pb2,
    wrappers_pb2,
    status_pb2,
    date_pb2,
    latlng_pb2,
    money_pb2,
    postal_address_pb2,
    timeofday_pb2,
]

_local_modules = [
    application_pb2,
    application_service_pb2,
    common_pb2,
    company_pb2,
    company_service_pb2,
    completion_service_pb2,
    event_pb2,
    event_service_pb2,
    filters_pb2,
    histogram_pb2,
    job_pb2,
    job_service_pb2,
    profile_pb2,
    profile_service_pb2,
    tenant_pb2,
    tenant_service_pb2,
]

names = []

for module in _shared_modules:  # pragma: NO COVER
    for name, message in get_messages(module).items():
        setattr(sys.modules[__name__], name, message)
        names.append(name)
for module in _local_modules:
    for name, message in get_messages(module).items():
        message.__module__ = "google.cloud.talent_v4beta1.types"
        setattr(sys.modules[__name__], name, message)
        names.append(name)


__all__ = tuple(sorted(names))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/talent_v4beta1/proto/application_service.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.talent_v4beta1.proto import (
    application_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__pb2,
)
from google.cloud.talent_v4beta1.proto import (
    common_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/talent_v4beta1/proto/application_service.proto",
    package="google.cloud.talent.v4beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.talent.v4beta1B\027ApplicationServiceProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\242\002\003CTS"
    ),
    serialized_pb=_b(
        '\n;google/cloud/talent_v4beta1/proto/application_service.proto\x12\x1bgoogle.cloud.talent.v4beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x33google/cloud/talent_v4beta1/proto/application.proto\x1a.google/cloud/talent_v4beta1/proto/common.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto"\x93\x01\n\x18\x43reateApplicationRequest\x12\x33\n\x06parent\x18\x01 \x01(\tB#\xe0\x41\x02\xfa\x41\x1d\n\x1bjobs.googleapis.com/Profile\x12\x42\n\x0b\x61pplication\x18\x02 \x01(\x0b\x32(.google.cloud.talent.v4beta1.ApplicationB\x03\xe0\x41\x02"N\n\x15GetApplicationRequest\x12\x35\n\x04name\x18\x01 \x01(\tB\'\xe0\x41\x02\xfa\x41!\n\x1fjobs.googleapis.com/Application"\x8f\x01\n\x18UpdateApplicationRequest\x12\x42\n\x0b\x61pplication\x18\x01 \x01(\x0b\x32(.google.cloud.talent.v4beta1.ApplicationB\x03\xe0\x41\x02\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"Q\n\x18\x44\x65leteApplicationRequest\x12\x35\n\x04name\x18\x01 \x01(\tB\'\xe0\x41\x02\xfa\x41!\n\x1fjobs.googleapis.com/Application"u\n\x17ListApplicationsRequest\x12\x33\n\x06parent\x18\x01 \x01(\tB#\xe0\x41\x02\xfa\x41\x1d\n\x1bjobs.googleapis.com/Profile\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05"\xb4\x01\n\x18ListApplicationsResponse\x12>\n\x0c\x61pplications\x18\x01 \x03(\x0b\x32(.google.cloud.talent.v4beta1.Application\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12?\n\x08metadata\x18\x03 \x01(\x0b\x32-.google.cloud.talent.v4beta1.ResponseMetadata2\xfc\x08\n\x12\x41pplicationService\x12\xd4\x01\n\x11\x43reateApplication\x12\x35.google.cloud.talent.v4beta1.CreateApplicationRequest\x1a(.google.cloud.talent.v4beta1.Application"^\x82\xd3\xe4\x93\x02\x43">/v4beta1/{parent=projects/*/tenants/*/profiles/*}/applications:\x01*\xda\x41\x12parent,application\x12\xbd\x01\n\x0eGetApplication\x12\x32.google.cloud.talent.v4beta1.GetApplicationRequest\x1a(.google.cloud.talent.v4beta1.Application"M\x82\xd3\xe4\x93\x02@\x12>/v4beta1/{name=projects/*/tenants/*/profiles/*/applications/*}\xda\x41\x04name\x12\xd9\x01\n\x11UpdateApplication\x12\x35.google.cloud.talent.v4beta1.UpdateApplicationRequest\x1a(.google.cloud.talent.v4beta1.Application"c\x82\xd3\xe4\x93\x02O2J/v4beta1/{application.name=projects/*/tenants/*/profiles/*/applications/*}:\x01*\xda\x41\x0b\x61pplication\x12\xb1\x01\n\x11\x44\x65leteApplication\x12\x35.google.cloud.talent.v4beta1.DeleteApplicationRequest\x1a\x16.google.protobuf.Empty"M\x82\xd3\xe4\x93\x02@*>/v4beta1/{name=projects/*/tenants/*/profiles/*/applications/*}\xda\x41\x04name\x12\xd0\x01\n\x10ListApplications\x12\x34.google.cloud.talent.v4beta1.ListApplicationsRequest\x1a\x35.google.cloud.talent.v4beta1.ListApplicationsResponse"O\x82\xd3\xe4\x93\x02@\x12>/v4beta1/{parent=projects/*/tenants/*/profiles/*}/applications\xda\x41\x06parent\x1al\xca\x41\x13jobs.googleapis.com\xd2\x41Shttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/jobsB\x85\x01\n\x1f\x63om.google.cloud.talent.v4beta1B\x17\x41pplicationServiceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\xa2\x02\x03\x43TSb\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
    ],
)


_CREATEAPPLICATIONREQUEST = _descriptor.Descriptor(
    name="CreateApplicationRequest",
    full_name="google.cloud.talent.v4beta1.CreateApplicationRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.talent.v4beta1.CreateApplicationRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b(
                "\340A\002\372A\035\n\033jobs.googleapis.com/Profile"
            ),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="application",
            full_name="google.cloud.talent.v4beta1.CreateApplicationRequest.application",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=372,
    serialized_end=519,
)


_GETAPPLICATIONREQUEST = _descriptor.Descriptor(
    name="GetApplicationRequest",
    full_name="google.cloud.talent.v4beta1.GetApplicationRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.talent.v4beta1.GetApplicationRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b(
                "\340A\002\372A!\n\037jobs.googleapis.com/Application"
            ),
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=521,
    serialized_end=599,
)


_UPDATEAPPLICATIONREQUEST = _descriptor.Descriptor(
    name="UpdateApplicationRequest",
    full_name="google.cloud.talent.v4beta1.UpdateApplicationRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="application",
            full_name="google.cloud.talent.v4beta1.UpdateApplicationRequest.application",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.talent.v4beta1.UpdateApplicationRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=602,
    serialized_end=745,
)


_DELETEAPPLICATIONREQUEST = _descriptor.Descriptor(
    name="DeleteApplicationRequest",
    full_name="google.cloud.talent.v4beta1.DeleteApplicationRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.talent.v4beta1.DeleteApplicationRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b(
                "\340A\002\372A!\n\037jobs.googleapis.com/Application"
            ),
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=747,
    serialized_end=828,
)


_LISTAPPLICATIONSREQUEST = _descriptor.Descriptor(
    name="ListApplicationsRequest",
    full_name="google.cloud.talent.v4beta1.ListApplicationsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.talent.v4beta1.ListApplicationsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b(
                "\340A\002\372A\035\n\033jobs.googleapis.com/Profile"
            ),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.talent.v4beta1.ListApplicationsRequest.page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.talent.v4beta1.ListApplicationsRequest.page_size",
            index=2,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=830,
    serialized_end=947,
)


_LISTAPPLICATIONSRESPONSE = _descriptor.Descriptor(
    name="ListApplicationsResponse",
    full_name="google.cloud.talent.v4beta1.ListApplicationsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="applications",
            full_name="google.cloud.talent.v4beta1.ListApplicationsResponse.applications",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.talent.v4beta1.ListApplicationsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="google.cloud.talent.v4beta1.ListApplicationsResponse.metadata",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=950,
    serialized_end=1130,
)

_CREATEAPPLICATIONREQUEST.fields_by_name[
    "application"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__pb2._APPLICATION
)
_UPDATEAPPLICATIONREQUEST.fields_by_name[
    "application"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__pb2._APPLICATION
)
_UPDATEAPPLICATIONREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTAPPLICATIONSRESPONSE.fields_by_name[
    "applications"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__pb2._APPLICATION
)
_LISTAPPLICATIONSRESPONSE.fields_by_name[
    "metadata"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._RESPONSEMETADATA
)
DESCRIPTOR.message_types_by_name["CreateApplicationRequest"] = _CREATEAPPLICATIONREQUEST
DESCRIPTOR.message_types_by_name["GetApplicationRequest"] = _GETAPPLICATIONREQUEST
DESCRIPTOR.message_types_by_name["UpdateApplicationRequest"] = _UPDATEAPPLICATIONREQUEST
DESCRIPTOR.message_types_by_name["DeleteApplicationRequest"] = _DELETEAPPLICATIONREQUEST
DESCRIPTOR.message_types_by_name["ListApplicationsRequest"] = _LISTAPPLICATIONSREQUEST
DESCRIPTOR.message_types_by_name["ListApplicationsResponse"] = _LISTAPPLICATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateApplicationRequest = _reflection.GeneratedProtocolMessageType(
    "CreateApplicationRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CREATEAPPLICATIONREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.application_service_pb2",
        __doc__="""The Request of the CreateApplication method.
  
  
  Attributes:
      parent:
          Required. Resource name of the profile under which the
          application is created.  The format is "projects/{project\_id}
          /tenants/{tenant\_id}/profiles/{profile\_id}". For example,
          "projects/foo/tenants/bar/profiles/baz".
      application:
          Required. The application to be created.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.CreateApplicationRequest)
    ),
)
_sym_db.RegisterMessage(CreateApplicationRequest)

GetApplicationRequest = _reflection.GeneratedProtocolMessageType(
    "GetApplicationRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETAPPLICATIONREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.application_service_pb2",
        __doc__="""Request for getting a application by name.
  
  
  Attributes:
      name:
          Required. The resource name of the application to be
          retrieved.  The format is "projects/{project\_id}/tenants/{ten
          ant\_id}/profiles/{profile\_id}/applications/{application\_id}
          ". For example,
          "projects/foo/tenants/bar/profiles/baz/applications/qux".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.GetApplicationRequest)
    ),
)
_sym_db.RegisterMessage(GetApplicationRequest)

UpdateApplicationRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateApplicationRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UPDATEAPPLICATIONREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.application_service_pb2",
        __doc__="""Request for updating a specified application.
  
  
  Attributes:
      application:
          Required. The application resource to replace the current
          resource in the system.
      update_mask:
          Strongly recommended for the best service experience.  If [upd
          ate\_mask][google.cloud.talent.v4beta1.UpdateApplicationReques
          t.update\_mask] is provided, only the specified fields in [app
          lication][google.cloud.talent.v4beta1.UpdateApplicationRequest
          .application] are updated. Otherwise all the fields are
          updated.  A field mask to specify the application fields to be
          updated. Only top level fields of
          [Application][google.cloud.talent.v4beta1.Application] are
          supported.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.UpdateApplicationRequest)
    ),
)
_sym_db.RegisterMessage(UpdateApplicationRequest)

DeleteApplicationRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteApplicationRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DELETEAPPLICATIONREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.application_service_pb2",
        __doc__="""Request to delete a application.
  
  
  Attributes:
      name:
          Required. The resource name of the application to be deleted.
          The format is "projects/{project\_id}/tenants/{tenant\_id}/pro
          files/{profile\_id}/applications/{application\_id}". For
          example,
          "projects/foo/tenants/bar/profiles/baz/applications/qux".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.DeleteApplicationRequest)
    ),
)
_sym_db.RegisterMessage(DeleteApplicationRequest)

ListApplicationsRequest = _reflection.GeneratedProtocolMessageType(
    "ListApplicationsRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTAPPLICATIONSREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.application_service_pb2",
        __doc__="""List applications for which the client has ACL visibility.
  
  
  Attributes:
      parent:
          Required. Resource name of the profile under which the
          application is created.  The format is "projects/{project\_id}
          /tenants/{tenant\_id}/profiles/{profile\_id}", for example,
          "projects/foo/tenants/bar/profiles/baz".
      page_token:
          The starting indicator from which to return results.
      page_size:
          The maximum number of applications to be returned, at most
          100. Default is 100 if a non-positive number is provided.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.ListApplicationsRequest)
    ),
)
_sym_db.RegisterMessage(ListApplicationsRequest)

ListApplicationsResponse = _reflection.GeneratedProtocolMessageType(
    "ListApplicationsResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTAPPLICATIONSRESPONSE,
        __module__="google.cloud.talent_v4beta1.proto.application_service_pb2",
        __doc__="""The List applications response object.
  
  
  Attributes:
      applications:
          Applications for the current client.
      next_page_token:
          A token to retrieve the next page of results.
      metadata:
          Additional information for the API invocation, such as the
          request tracking id.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.ListApplicationsResponse)
    ),
)
_sym_db.RegisterMessage(ListApplicationsResponse)


DESCRIPTOR._options = None
_CREATEAPPLICATIONREQUEST.fields_by_name["parent"]._options = None
_CREATEAPPLICATIONREQUEST.fields_by_name["application"]._options = None
_GETAPPLICATIONREQUEST.fields_by_name["name"]._options = None
_UPDATEAPPLICATIONREQUEST.fields_by_name["application"]._options = None
_DELETEAPPLICATIONREQUEST.fields_by_name["name"]._options = None
_LISTAPPLICATIONSREQUEST.fields_by_name["parent"]._options = None

_APPLICATIONSERVICE = _descriptor.ServiceDescriptor(
    name="ApplicationService",
    full_name="google.cloud.talent.v4beta1.ApplicationService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=_b(
        "\312A\023jobs.googleapis.com\322AShttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/jobs"
    ),
    serialized_start=1133,
    serialized_end=2281,
    methods=[
        _descriptor.MethodDescriptor(
            name="CreateApplication",
            full_name="google.cloud.talent.v4beta1.ApplicationService.CreateApplication",
            index=0,
            containing_service=None,
            input_type=_CREATEAPPLICATIONREQUEST,
            output_type=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__pb2._APPLICATION,
            serialized_options=_b(
                '\202\323\344\223\002C">/v4beta1/{parent=projects/*/tenants/*/profiles/*}/applications:\001*\332A\022parent,application'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetApplication",
            full_name="google.cloud.talent.v4beta1.ApplicationService.GetApplication",
            index=1,
            containing_service=None,
            input_type=_GETAPPLICATIONREQUEST,
            output_type=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__pb2._APPLICATION,
            serialized_options=_b(
                "\202\323\344\223\002@\022>/v4beta1/{name=projects/*/tenants/*/profiles/*/applications/*}\332A\004name"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UpdateApplication",
            full_name="google.cloud.talent.v4beta1.ApplicationService.UpdateApplication",
            index=2,
            containing_service=None,
            input_type=_UPDATEAPPLICATIONREQUEST,
            output_type=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_application__pb2._APPLICATION,
            serialized_options=_b(
                "\202\323\344\223\002O2J/v4beta1/{application.name=projects/*/tenants/*/profiles/*/applications/*}:\001*\332A\013application"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="DeleteApplication",
            full_name="google.cloud.talent.v4beta1.ApplicationService.DeleteApplication",
            index=3,
            containing_service=None,
            input_type=_DELETEAPPLICATIONREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=_b(
                "\202\323\344\223\002@*>/v4beta1/{name=projects/*/tenants/*/profiles/*/applications/*}\332A\004name"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ListApplications",
            full_name="google.cloud.talent.v4beta1.ApplicationService.ListApplications",
            index=4,
            containing_service=None,
            input_type=_LISTAPPLICATIONSREQUEST,
            output_type=_LISTAPPLICATIONSRESPONSE,
            serialized_options=_b(
                "\202\323\344\223\002@\022>/v4beta1/{parent=projects/*/tenants/*/profiles/*}/applications\332A\006parent"
            ),
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_APPLICATIONSERVICE)

DESCRIPTOR.services_by_name["ApplicationService"] = _APPLICATIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/talent_v4beta1/proto/batch.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/talent_v4beta1/proto/batch.proto",
    package="google.cloud.talent.v4beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.talent.v4beta1B\nBatchProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\242\002\003CTS"
    ),
    serialized_pb=_b(
        "\n-google/cloud/talent_v4beta1/proto/batch.proto\x12\x1bgoogle.cloud.talent.v4beta1\x1a\x1cgoogle/api/annotations.protoBx\n\x1f\x63om.google.cloud.talent.v4beta1B\nBatchProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\xa2\x02\x03\x43TSb\x06proto3"
    ),
    dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR],
)


_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/talent_v4beta1/proto/tenant_service.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.talent_v4beta1.proto import (
    common_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2,
)
from google.cloud.talent_v4beta1.proto import (
    tenant_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/talent_v4beta1/proto/tenant_service.proto",
    package="google.cloud.talent.v4beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.talent.v4beta1B\022TenantServiceProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\242\002\003CTS"
    ),
    serialized_pb=_b(
        '\n6google/cloud/talent_v4beta1/proto/tenant_service.proto\x12\x1bgoogle.cloud.talent.v4beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a.google/cloud/talent_v4beta1/proto/common.proto\x1a.google/cloud/talent_v4beta1/proto/tenant.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto"\x94\x01\n\x13\x43reateTenantRequest\x12\x43\n\x06parent\x18\x01 \x01(\tB3\xe0\x41\x02\xfa\x41-\n+cloudresourcemanager.googleapis.com/Project\x12\x38\n\x06tenant\x18\x02 \x01(\x0b\x32#.google.cloud.talent.v4beta1.TenantB\x03\xe0\x41\x02"D\n\x10GetTenantRequest\x12\x30\n\x04name\x18\x01 \x01(\tB"\xe0\x41\x02\xfa\x41\x1c\n\x1ajobs.googleapis.com/Tenant"\x80\x01\n\x13UpdateTenantRequest\x12\x38\n\x06tenant\x18\x01 \x01(\x0b\x32#.google.cloud.talent.v4beta1.TenantB\x03\xe0\x41\x02\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"G\n\x13\x44\x65leteTenantRequest\x12\x30\n\x04name\x18\x01 \x01(\tB"\xe0\x41\x02\xfa\x41\x1c\n\x1ajobs.googleapis.com/Tenant"\x80\x01\n\x12ListTenantsRequest\x12\x43\n\x06parent\x18\x01 \x01(\tB3\xe0\x41\x02\xfa\x41-\n+cloudresourcemanager.googleapis.com/Project\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05"\xa5\x01\n\x13ListTenantsResponse\x12\x34\n\x07tenants\x18\x01 \x03(\x0b\x32#.google.cloud.talent.v4beta1.Tenant\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12?\n\x08metadata\x18\x03 \x01(\x0b\x32-.google.cloud.talent.v4beta1.ResponseMetadata2\xa0\x07\n\rTenantService\x12\xa6\x01\n\x0c\x43reateTenant\x12\x30.google.cloud.talent.v4beta1.CreateTenantRequest\x1a#.google.cloud.talent.v4beta1.Tenant"?\x82\xd3\xe4\x93\x02)"$/v4beta1/{parent=projects/*}/tenants:\x01*\xda\x41\rparent,tenant\x12\x94\x01\n\tGetTenant\x12-.google.cloud.talent.v4beta1.GetTenantRequest\x1a#.google.cloud.talent.v4beta1.Tenant"3\x82\xd3\xe4\x93\x02&\x12$/v4beta1/{name=projects/*/tenants/*}\xda\x41\x04name\x12\xa6\x01\n\x0cUpdateTenant\x12\x30.google.cloud.talent.v4beta1.UpdateTenantRequest\x1a#.google.cloud.talent.v4beta1.Tenant"?\x82\xd3\xe4\x93\x02\x30\x32+/v4beta1/{tenant.name=projects/*/tenants/*}:\x01*\xda\x41\x06tenant\x12\x8d\x01\n\x0c\x44\x65leteTenant\x12\x30.google.cloud.talent.v4beta1.DeleteTenantRequest\x1a\x16.google.protobuf.Empty"3\x82\xd3\xe4\x93\x02&*$/v4beta1/{name=projects/*/tenants/*}\xda\x41\x04name\x12\xa7\x01\n\x0bListTenants\x12/.google.cloud.talent.v4beta1.ListTenantsRequest\x1a\x30.google.cloud.talent.v4beta1.ListTenantsResponse"5\x82\xd3\xe4\x93\x02&\x12$/v4beta1/{parent=projects/*}/tenants\xda\x41\x06parent\x1al\xca\x41\x13jobs.googleapis.com\xd2\x41Shttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/jobsB\x80\x01\n\x1f\x63om.google.cloud.talent.v4beta1B\x12TenantServiceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\xa2\x02\x03\x43TSb\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
    ],
)


_CREATETENANTREQUEST = _descriptor.Descriptor(
    name="CreateTenantRequest",
    full_name="google.cloud.talent.v4beta1.CreateTenantRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.talent.v4beta1.CreateTenantRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b(
                "\340A\002\372A-\n+cloudresourcemanager.googleapis.com/Project"
            ),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tenant",
            full_name="google.cloud.talent.v4beta1.CreateTenantRequest.tenant",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=362,
    serialized_end=510,
)


_GETTENANTREQUEST = _descriptor.Descriptor(
    name="GetTenantRequest",
    full_name="google.cloud.talent.v4beta1.GetTenantRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.talent.v4beta1.GetTenantRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002\372A\034\n\032jobs.googleapis.com/Tenant"),
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=512,
    serialized_end=580,
)


_UPDATETENANTREQUEST = _descriptor.Descriptor(
    name="UpdateTenantRequest",
    full_name="google.cloud.talent.v4beta1.UpdateTenantRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="tenant",
            full_name="google.cloud.talent.v4beta1.UpdateTenantRequest.tenant",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.talent.v4beta1.UpdateTenantRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=583,
    serialized_end=711,
)


_DELETETENANTREQUEST = _descriptor.Descriptor(
    name="DeleteTenantRequest",
    full_name="google.cloud.talent.v4beta1.DeleteTenantRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.talent.v4beta1.DeleteTenantRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002\372A\034\n\032jobs.googleapis.com/Tenant"),
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=713,
    serialized_end=784,
)


_LISTTENANTSREQUEST = _descriptor.Descriptor(
    name="ListTenantsRequest",
    full_name="google.cloud.talent.v4beta1.ListTenantsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.talent.v4beta1.ListTenantsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b(
                "\340A\002\372A-\n+cloudresourcemanager.googleapis.com/Project"
            ),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.talent.v4beta1.ListTenantsRequest.page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.talent.v4beta1.ListTenantsRequest.page_size",
            index=2,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=787,
    serialized_end=915,
)


_LISTTENANTSRESPONSE = _descriptor.Descriptor(
    name="ListTenantsResponse",
    full_name="google.cloud.talent.v4beta1.ListTenantsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="tenants",
            full_name="google.cloud.talent.v4beta1.ListTenantsResponse.tenants",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.talent.v4beta1.ListTenantsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="google.cloud.talent.v4beta1.ListTenantsResponse.metadata",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=918,
    serialized_end=1083,
)

_CREATETENANTREQUEST.fields_by_name[
    "tenant"
].message_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__pb2._TENANT
_UPDATETENANTREQUEST.fields_by_name[
    "tenant"
].message_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__pb2._TENANT
_UPDATETENANTREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTTENANTSRESPONSE.fields_by_name[
    "tenants"
].message_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__pb2._TENANT
_LISTTENANTSRESPONSE.fields_by_name[
    "metadata"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._RESPONSEMETADATA
)
DESCRIPTOR.message_types_by_name["CreateTenantRequest"] = _CREATETENANTREQUEST
DESCRIPTOR.message_types_by_name["GetTenantRequest"] = _GETTENANTREQUEST
DESCRIPTOR.message_types_by_name["UpdateTenantRequest"] = _UPDATETENANTREQUEST
DESCRIPTOR.message_types_by_name["DeleteTenantRequest"] = _DELETETENANTREQUEST
DESCRIPTOR.message_types_by_name["ListTenantsRequest"] = _LISTTENANTSREQUEST
DESCRIPTOR.message_types_by_name["ListTenantsResponse"] = _LISTTENANTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateTenantRequest = _reflection.GeneratedProtocolMessageType(
    "CreateTenantRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CREATETENANTREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.tenant_service_pb2",
        __doc__="""The Request of the CreateTenant method.
  
  
  Attributes:
      parent:
          Required. Resource name of the project under which the tenant
          is created.  The format is "projects/{project\_id}", for
          example, "projects/foo".
      tenant:
          Required. The tenant to be created.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.CreateTenantRequest)
    ),
)
_sym_db.RegisterMessage(CreateTenantRequest)

GetTenantRequest = _reflection.GeneratedProtocolMessageType(
    "GetTenantRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETTENANTREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.tenant_service_pb2",
        __doc__="""Request for getting a tenant by name.
  
  
  Attributes:
      name:
          Required. The resource name of the tenant to be retrieved.
          The format is "projects/{project\_id}/tenants/{tenant\_id}",
          for example, "projects/foo/tenants/bar".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.GetTenantRequest)
    ),
)
_sym_db.RegisterMessage(GetTenantRequest)

UpdateTenantRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateTenantRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UPDATETENANTREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.tenant_service_pb2",
        __doc__="""Request for updating a specified tenant.
  
  
  Attributes:
      tenant:
          Required. The tenant resource to replace the current resource
          in the system.
      update_mask:
          Strongly recommended for the best service experience.  If [upd
          ate\_mask][google.cloud.talent.v4beta1.UpdateTenantRequest.upd
          ate\_mask] is provided, only the specified fields in [tenant][
          google.cloud.talent.v4beta1.UpdateTenantRequest.tenant] are
          updated. Otherwise all the fields are updated.  A field mask
          to specify the tenant fields to be updated. Only top level
          fields of [Tenant][google.cloud.talent.v4beta1.Tenant] are
          supported.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.UpdateTenantRequest)
    ),
)
_sym_db.RegisterMessage(UpdateTenantRequest)

DeleteTenantRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteTenantRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DELETETENANTREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.tenant_service_pb2",
        __doc__="""Request to delete a tenant.
  
  
  Attributes:
      name:
          Required. The resource name of the tenant to be deleted.  The
          format is "projects/{project\_id}/tenants/{tenant\_id}", for
          example, "projects/foo/tenants/bar".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.DeleteTenantRequest)
    ),
)
_sym_db.RegisterMessage(DeleteTenantRequest)

ListTenantsRequest = _reflection.GeneratedProtocolMessageType(
    "ListTenantsRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTTENANTSREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.tenant_service_pb2",
        __doc__="""List tenants for which the client has ACL visibility.
  
  
  Attributes:
      parent:
          Required. Resource name of the project under which the tenant
          is created.  The format is "projects/{project\_id}", for
          example, "projects/foo".
      page_token:
          The starting indicator from which to return results.
      page_size:
          The maximum number of tenants to be returned, at most 100.
          Default is 100 if a non-positive number is provided.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.ListTenantsRequest)
    ),
)
_sym_db.RegisterMessage(ListTenantsRequest)

ListTenantsResponse = _reflection.GeneratedProtocolMessageType(
    "ListTenantsResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTTENANTSRESPONSE,
        __module__="google.cloud.talent_v4beta1.proto.tenant_service_pb2",
        __doc__="""The List tenants response object.
  
  
  Attributes:
      tenants:
          Tenants for the current client.
      next_page_token:
          A token to retrieve the next page of results.
      metadata:
          Additional information for the API invocation, such as the
          request tracking id.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.ListTenantsResponse)
    ),
)
_sym_db.RegisterMessage(ListTenantsResponse)


DESCRIPTOR._options = None
_CREATETENANTREQUEST.fields_by_name["parent"]._options = None
_CREATETENANTREQUEST.fields_by_name["tenant"]._options = None
_GETTENANTREQUEST.fields_by_name["name"]._options = None
_UPDATETENANTREQUEST.fields_by_name["tenant"]._options = None
_DELETETENANTREQUEST.fields_by_name["name"]._options = None
_LISTTENANTSREQUEST.fields_by_name["parent"]._options = None

_TENANTSERVICE = _descriptor.ServiceDescriptor(
    name="TenantService",
    full_name="google.cloud.talent.v4beta1.TenantService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=_b(
        "\312A\023jobs.googleapis.com\322AShttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/jobs"
    ),
    serialized_start=1086,
    serialized_end=2014,
    methods=[
        _descriptor.MethodDescriptor(
            name="CreateTenant",
            full_name="google.cloud.talent.v4beta1.TenantService.CreateTenant",
            index=0,
            containing_service=None,
            input_type=_CREATETENANTREQUEST,
            output_type=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__pb2._TENANT,
            serialized_options=_b(
                '\202\323\344\223\002)"$/v4beta1/{parent=projects/*}/tenants:\001*\332A\rparent,tenant'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetTenant",
            full_name="google.cloud.talent.v4beta1.TenantService.GetTenant",
            index=1,
            containing_service=None,
            input_type=_GETTENANTREQUEST,
            output_type=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__pb2._TENANT,
            serialized_options=_b(
                "\202\323\344\223\002&\022$/v4beta1/{name=projects/*/tenants/*}\332A\004name"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UpdateTenant",
            full_name="google.cloud.talent.v4beta1.TenantService.UpdateTenant",
            index=2,
            containing_service=None,
            input_type=_UPDATETENANTREQUEST,
            output_type=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_tenant__pb2._TENANT,
            serialized_options=_b(
                "\202\323\344\223\00202+/v4beta1/{tenant.name=projects/*/tenants/*}:\001*\332A\006tenant"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="DeleteTenant",
            full_name="google.cloud.talent.v4beta1.TenantService.DeleteTenant",
            index=3,
            containing_service=None,
            input_type=_DELETETENANTREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=_b(
                "\202\323\344\223\002&*$/v4beta1/{name=projects/*/tenants/*}\332A\004name"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ListTenants",
            full_name="google.cloud.talent.v4beta1.TenantService.ListTenants",
            index=4,
            containing_service=None,
            input_type=_LISTTENANTSREQUEST,
            output_type=_LISTTENANTSRESPONSE,
            serialized_options=_b(
                "\202\323\344\223\002&\022$/v4beta1/{parent=projects/*}/tenants\332A\006parent"
            ),
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_TENANTSERVICE)

DESCRIPTOR.services_by_name["TenantService"] = _TENANTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/talent_v4beta1/proto/company.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.talent_v4beta1.proto import (
    common_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2,
)
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/talent_v4beta1/proto/company.proto",
    package="google.cloud.talent.v4beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.talent.v4beta1B\024CompanyResourceProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\242\002\003CTS"
    ),
    serialized_pb=_b(
        '\n/google/cloud/talent_v4beta1/proto/company.proto\x12\x1bgoogle.cloud.talent.v4beta1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a.google/cloud/talent_v4beta1/proto/common.proto\x1a\x1cgoogle/api/annotations.proto"\xfc\x04\n\x07\x43ompany\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x18\n\x0b\x65xternal_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12\x36\n\x04size\x18\x04 \x01(\x0e\x32(.google.cloud.talent.v4beta1.CompanySize\x12\x1c\n\x14headquarters_address\x18\x05 \x01(\t\x12\x15\n\rhiring_agency\x18\x06 \x01(\x08\x12\x10\n\x08\x65\x65o_text\x18\x07 \x01(\t\x12\x13\n\x0bwebsite_uri\x18\x08 \x01(\t\x12\x17\n\x0f\x63\x61reer_site_uri\x18\t \x01(\t\x12\x11\n\timage_uri\x18\n \x01(\t\x12\x30\n(keyword_searchable_job_custom_attributes\x18\x0b \x03(\t\x12K\n\x0c\x64\x65rived_info\x18\x0c \x01(\x0b\x32\x30.google.cloud.talent.v4beta1.Company.DerivedInfoB\x03\xe0\x41\x03\x12\x16\n\tsuspended\x18\r \x01(\x08\x42\x03\xe0\x41\x03\x1aS\n\x0b\x44\x65rivedInfo\x12\x44\n\x15headquarters_location\x18\x01 \x01(\x0b\x32%.google.cloud.talent.v4beta1.Location:\x81\x01\xea\x41~\n\x1bjobs.googleapis.com/Company\x12&projects/{project}/companies/{company}\x12\x37projects/{project}/tenants/{tenant}/companies/{company}B\x82\x01\n\x1f\x63om.google.cloud.talent.v4beta1B\x14\x43ompanyResourceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\xa2\x02\x03\x43TSb\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2.DESCRIPTOR,
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
    ],
)


_COMPANY_DERIVEDINFO = _descriptor.Descriptor(
    name="DerivedInfo",
    full_name="google.cloud.talent.v4beta1.Company.DerivedInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="headquarters_location",
            full_name="google.cloud.talent.v4beta1.Company.DerivedInfo.headquarters_location",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=640,
    serialized_end=723,
)

_COMPANY = _descriptor.Descriptor(
    name="Company",
    full_name="google.cloud.talent.v4beta1.Company",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.talent.v4beta1.Company.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.talent.v4beta1.Company.display_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="external_id",
            full_name="google.cloud.talent.v4beta1.Company.external_id",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="size",
            full_name="google.cloud.talent.v4beta1.Company.size",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="headquarters_address",
            full_name="google.cloud.talent.v4beta1.Company.headquarters_address",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="hiring_agency",
            full_name="google.cloud.talent.v4beta1.Company.hiring_agency",
            index=5,
            number=6,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="eeo_text",
            full_name="google.cloud.talent.v4beta1.Company.eeo_text",
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="website_uri",
            full_name="google.cloud.talent.v4beta1.Company.website_uri",
            index=7,
            number=8,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="career_site_uri",
            full_name="google.cloud.talent.v4beta1.Company.career_site_uri",
            index=8,
            number=9,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="image_uri",
            full_name="google.cloud.talent.v4beta1.Company.image_uri",
            index=9,
            number=10,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="keyword_searchable_job_custom_attributes",
            full_name="google.cloud.talent.v4beta1.Company.keyword_searchable_job_custom_attributes",
            index=10,
            number=11,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="derived_info",
            full_name="google.cloud.talent.v4beta1.Company.derived_info",
            index=11,
            number=12,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="suspended",
            full_name="google.cloud.talent.v4beta1.Company.suspended",
            index=12,
            number=13,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_COMPANY_DERIVEDINFO],
    enum_types=[],
    serialized_options=_b(
        "\352A~\n\033jobs.googleapis.com/Company\022&projects/{project}/companies/{company}\0227projects/{project}/tenants/{tenant}/companies/{company}"
    ),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=219,
    serialized_end=855,
)

_COMPANY_DERIVEDINFO.fields_by_name[
    "headquarters_location"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._LOCATION
)
_COMPANY_DERIVEDINFO.containing_type = _COMPANY
_COMPANY.fields_by_name[
    "size"
].enum_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._COMPANYSIZE
)
_COMPANY.fields_by_name["derived_info"].message_type = _COMPANY_DERIVEDINFO
DESCRIPTOR.message_types_by_name["Company"] = _COMPANY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Company = _reflection.GeneratedProtocolMessageType(
    "Company",
    (_message.Message,),
    dict(
        DerivedInfo=_reflection.GeneratedProtocolMessageType(
            "DerivedInfo",
            (_message.Message,),
            dict(
                DESCRIPTOR=_COMPANY_DERIVEDINFO,
                __module__="google.cloud.talent_v4beta1.proto.company_pb2",
                __doc__="""Derived details about the company.
    
    
    Attributes:
        headquarters_location:
            A structured headquarters location of the company, resolved
            from [Company.headquarters\_address][google.cloud.talent.v4bet
            a1.Company.headquarters\_address] if provided.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Company.DerivedInfo)
            ),
        ),
        DESCRIPTOR=_COMPANY,
        __module__="google.cloud.talent_v4beta1.proto.company_pb2",
        __doc__="""A Company resource represents a company in the service. A
  company is the entity that owns job postings, that is, the hiring entity
  responsible for employing applicants for the job position.
  
  
  Attributes:
      name:
          Required during company update.  The resource name for a
          company. This is generated by the service when a company is
          created.  The format is "projects/{project\_id}/tenants/{tenan
          t\_id}/companies/{company\_id}", for example,
          "projects/foo/tenants/bar/companies/baz".  If tenant id is
          unspecified, the default tenant is used. For example,
          "projects/foo/companies/bar".
      display_name:
          Required. The display name of the company, for example,
          "Google LLC".
      external_id:
          Required. Client side company identifier, used to uniquely
          identify the company.  The maximum number of allowed
          characters is 255.
      size:
          The employer's company size.
      headquarters_address:
          The street address of the company's main headquarters, which
          may be different from the job location. The service attempts
          to geolocate the provided address, and populates a more
          specific location wherever possible in [DerivedInfo.headquarte
          rs\_location][google.cloud.talent.v4beta1.Company.DerivedInfo.
          headquarters\_location].
      hiring_agency:
          Set to true if it is the hiring agency that post jobs for
          other employers.  Defaults to false if not provided.
      eeo_text:
          Equal Employment Opportunity legal disclaimer text to be
          associated with all jobs, and typically to be displayed in all
          roles.  The maximum number of allowed characters is 500.
      website_uri:
          The URI representing the company's primary web site or home
          page, for example, "https://www.google.com".  The maximum
          number of allowed characters is 255.
      career_site_uri:
          The URI to employer's career site or careers page on the
          employer's web site, for example,
          "https://careers.google.com".
      image_uri:
          A URI that hosts the employer's company logo.
      keyword_searchable_job_custom_attributes:
          A list of keys of filterable [Job.custom\_attributes][google.c
          loud.talent.v4beta1.Job.custom\_attributes], whose
          corresponding ``string_values`` are used in keyword searches.
          Jobs with ``string_values`` under these specified field keys
          are returned if any of the values match the search keyword.
          Custom field values with parenthesis, brackets and special
          symbols are not searchable as-is, and those keyword queries
          must be surrounded by quotes.
      derived_info:
          Output only. Derived details about the company.
      suspended:
          Output only. Indicates whether a company is flagged to be
          suspended from public availability by the service when job
          content appears suspicious, abusive, or spammy.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Company)
    ),
)
_sym_db.RegisterMessage(Company)
_sym_db.RegisterMessage(Company.DerivedInfo)


DESCRIPTOR._options = None
_COMPANY.fields_by_name["display_name"]._options = None
_COMPANY.fields_by_name["external_id"]._options = None
_COMPANY.fields_by_name["derived_info"]._options = None
_COMPANY.fields_by_name["suspended"]._options = None
_COMPANY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/talent_v4beta1/proto/application.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.talent_v4beta1.proto import (
    common_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2,
)
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/talent_v4beta1/proto/application.proto",
    package="google.cloud.talent.v4beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.talent.v4beta1B\030ApplicationResourceProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\242\002\003CTS"
    ),
    serialized_pb=_b(
        '\n3google/cloud/talent_v4beta1/proto/application.proto\x12\x1bgoogle.cloud.talent.v4beta1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a.google/cloud/talent_v4beta1/proto/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16google/type/date.proto\x1a\x1cgoogle/api/annotations.proto"\x99\t\n\x0b\x41pplication\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x0b\x65xternal_id\x18\x1f \x01(\tB\x03\xe0\x41\x02\x12\x14\n\x07profile\x18\x02 \x01(\tB\x03\xe0\x41\x03\x12)\n\x03job\x18\x04 \x01(\tB\x1c\xfa\x41\x19\n\x17jobs.googleapis.com/Job\x12\x31\n\x07\x63ompany\x18\x05 \x01(\tB \xfa\x41\x1d\n\x1bjobs.googleapis.com/Company\x12+\n\x10\x61pplication_date\x18\x07 \x01(\x0b\x32\x11.google.type.Date\x12M\n\x05stage\x18\x0b \x01(\x0e\x32\x39.google.cloud.talent.v4beta1.Application.ApplicationStageB\x03\xe0\x41\x02\x12H\n\x05state\x18\r \x01(\x0e\x32\x39.google.cloud.talent.v4beta1.Application.ApplicationState\x12:\n\ninterviews\x18\x10 \x03(\x0b\x32&.google.cloud.talent.v4beta1.Interview\x12,\n\x08referral\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x0b\x63reate_time\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x02\x12/\n\x0bupdate_time\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\routcome_notes\x18\x15 \x01(\t\x12\x35\n\x07outcome\x18\x16 \x01(\x0e\x32$.google.cloud.talent.v4beta1.Outcome\x12\x31\n\x08is_match\x18\x1c \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x03\xe0\x41\x03\x12\x1e\n\x11job_title_snippet\x18\x1d \x01(\tB\x03\xe0\x41\x03"\x90\x01\n\x10\x41pplicationState\x12!\n\x1d\x41PPLICATION_STATE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bIN_PROGRESS\x10\x01\x12\x16\n\x12\x43\x41NDIDATE_WITHDREW\x10\x02\x12\x15\n\x11\x45MPLOYER_WITHDREW\x10\x03\x12\r\n\tCOMPLETED\x10\x04\x12\n\n\x06\x43LOSED\x10\x05"\xa9\x01\n\x10\x41pplicationStage\x12!\n\x1d\x41PPLICATION_STAGE_UNSPECIFIED\x10\x00\x12\x07\n\x03NEW\x10\x01\x12\n\n\x06SCREEN\x10\x02\x12\x19\n\x15HIRING_MANAGER_REVIEW\x10\x03\x12\r\n\tINTERVIEW\x10\x04\x12\x12\n\x0eOFFER_EXTENDED\x10\x05\x12\x12\n\x0eOFFER_ACCEPTED\x10\x06\x12\x0b\n\x07STARTED\x10\x07:w\xea\x41t\n\x1fjobs.googleapis.com/Application\x12Qprojects/{project}/tenants/{tenant}/profiles/{profile}/applications/{application}B\x86\x01\n\x1f\x63om.google.cloud.talent.v4beta1B\x18\x41pplicationResourceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\xa2\x02\x03\x43TSb\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,
        google_dot_type_dot_date__pb2.DESCRIPTOR,
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
    ],
)


_APPLICATION_APPLICATIONSTATE = _descriptor.EnumDescriptor(
    name="ApplicationState",
    full_name="google.cloud.talent.v4beta1.Application.ApplicationState",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="APPLICATION_STATE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="IN_PROGRESS", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="CANDIDATE_WITHDREW",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="EMPLOYER_WITHDREW",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="COMPLETED", index=4, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="CLOSED", index=5, number=5, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1052,
    serialized_end=1196,
)
_sym_db.RegisterEnumDescriptor(_APPLICATION_APPLICATIONSTATE)

_APPLICATION_APPLICATIONSTAGE = _descriptor.EnumDescriptor(
    name="ApplicationStage",
    full_name="google.cloud.talent.v4beta1.Application.ApplicationStage",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="APPLICATION_STAGE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="NEW", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="SCREEN", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="HIRING_MANAGER_REVIEW",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="INTERVIEW", index=4, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="OFFER_EXTENDED", index=5, number=5, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="OFFER_ACCEPTED", index=6, number=6, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="STARTED", index=7, number=7, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1199,
    serialized_end=1368,
)
_sym_db.RegisterEnumDescriptor(_APPLICATION_APPLICATIONSTAGE)


_APPLICATION = _descriptor.Descriptor(
    name="Application",
    full_name="google.cloud.talent.v4beta1.Application",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.talent.v4beta1.Application.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="external_id",
            full_name="google.cloud.talent.v4beta1.Application.external_id",
            index=1,
            number=31,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="profile",
            full_name="google.cloud.talent.v4beta1.Application.profile",
            index=2,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job",
            full_name="google.cloud.talent.v4beta1.Application.job",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\372A\031\n\027jobs.googleapis.com/Job"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="company",
            full_name="google.cloud.talent.v4beta1.Application.company",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\372A\035\n\033jobs.googleapis.com/Company"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="application_date",
            full_name="google.cloud.talent.v4beta1.Application.application_date",
            index=5,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="stage",
            full_name="google.cloud.talent.v4beta1.Application.stage",
            index=6,
            number=11,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="state",
            full_name="google.cloud.talent.v4beta1.Application.state",
            index=7,
            number=13,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="interviews",
            full_name="google.cloud.talent.v4beta1.Application.interviews",
            index=8,
            number=16,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="referral",
            full_name="google.cloud.talent.v4beta1.Application.referral",
            index=9,
            number=18,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="create_time",
            full_name="google.cloud.talent.v4beta1.Application.create_time",
            index=10,
            number=19,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_time",
            full_name="google.cloud.talent.v4beta1.Application.update_time",
            index=11,
            number=20,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="outcome_notes",
            full_name="google.cloud.talent.v4beta1.Application.outcome_notes",
            index=12,
            number=21,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="outcome",
            full_name="google.cloud.talent.v4beta1.Application.outcome",
            index=13,
            number=22,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="is_match",
            full_name="google.cloud.talent.v4beta1.Application.is_match",
            index=14,
            number=28,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_title_snippet",
            full_name="google.cloud.talent.v4beta1.Application.job_title_snippet",
            index=15,
            number=29,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_APPLICATION_APPLICATIONSTATE, _APPLICATION_APPLICATIONSTAGE],
    serialized_options=_b(
        "\352At\n\037jobs.googleapis.com/Application\022Qprojects/{project}/tenants/{tenant}/profiles/{profile}/applications/{application}"
    ),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=312,
    serialized_end=1489,
)

_APPLICATION.fields_by_name[
    "application_date"
].message_type = google_dot_type_dot_date__pb2._DATE
_APPLICATION.fields_by_name["stage"].enum_type = _APPLICATION_APPLICATIONSTAGE
_APPLICATION.fields_by_name["state"].enum_type = _APPLICATION_APPLICATIONSTATE
_APPLICATION.fields_by_name[
    "interviews"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._INTERVIEW
)
_APPLICATION.fields_by_name[
    "referral"
].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_APPLICATION.fields_by_name[
    "create_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_APPLICATION.fields_by_name[
    "update_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_APPLICATION.fields_by_name[
    "outcome"
].enum_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._OUTCOME
_APPLICATION.fields_by_name[
    "is_match"
].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_APPLICATION_APPLICATIONSTATE.containing_type = _APPLICATION
_APPLICATION_APPLICATIONSTAGE.containing_type = _APPLICATION
DESCRIPTOR.message_types_by_name["Application"] = _APPLICATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Application = _reflection.GeneratedProtocolMessageType(
    "Application",
    (_message.Message,),
    dict(
        DESCRIPTOR=_APPLICATION,
        __module__="google.cloud.talent_v4beta1.proto.application_pb2",
        __doc__="""Resource that represents a job application record of a
  candidate.
  
  
  Attributes:
      name:
          Required during application update.  Resource name assigned to
          an application by the API.  The format is "projects/{project\_
          id}/tenants/{tenant\_id}/profiles/{profile\_id}/applications/{
          application\_id}". For example,
          "projects/foo/tenants/bar/profiles/baz/applications/qux".
      external_id:
          Required. Client side application identifier, used to uniquely
          identify the application.  The maximum number of allowed
          characters is 255.
      profile:
          Output only. Resource name of the candidate of this
          application.  The format is "projects/{project\_id}/tenants/{t
          enant\_id}/profiles/{profile\_id}". For example,
          "projects/foo/tenants/bar/profiles/baz".
      job:
          One of either a job or a company is required.  Resource name
          of the job which the candidate applied for.  The format is
          "projects/{project\_id}/tenants/{tenant\_id}/jobs/{job\_id}".
          For example, "projects/foo/tenants/bar/jobs/baz".
      company:
          One of either a job or a company is required.  Resource name
          of the company which the candidate applied for.  The format is
          "projects/{project\_id}/tenants/{tenant\_id}/companies/{compan
          y\_id}". For example,
          "projects/foo/tenants/bar/companies/baz".
      application_date:
          The application date.
      stage:
          Required. What is the most recent stage of the application
          (that is, new, screen, send cv, hired, finished work)? This
          field is intentionally not comprehensive of every possible
          status, but instead, represents statuses that would be used to
          indicate to the ML models good / bad matches.
      state:
          The application state.
      interviews:
          All interviews (screen, onsite, and so on) conducted as part
          of this application (includes details such as user conducting
          the interview, timestamp, feedback, and so on).
      referral:
          If the candidate is referred by a employee.
      create_time:
          Required. Reflects the time that the application was created.
      update_time:
          The last update timestamp.
      outcome_notes:
          Free text reason behind the recruitement outcome (for example,
          reason for withdraw / reject, reason for an unsuccessful
          finish, and so on).  Number of characters allowed is 100.
      outcome:
          Outcome positiveness shows how positive the outcome is.
      is_match:
          Output only. Indicates whether this job application is a match
          to application related filters. This value is only applicable
          in profile search response.
      job_title_snippet:
          Output only. Job title snippet shows how the job title is
          related to a search query. It's empty if the job title isn't
          related to the search query.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Application)
    ),
)
_sym_db.RegisterMessage(Application)


DESCRIPTOR._options = None
_APPLICATION.fields_by_name["external_id"]._options = None
_APPLICATION.fields_by_name["profile"]._options = None
_APPLICATION.fields_by_name["job"]._options = None
_APPLICATION.fields_by_name["company"]._options = None
_APPLICATION.fields_by_name["stage"]._options = None
_APPLICATION.fields_by_name["create_time"]._options = None
_APPLICATION.fields_by_name["is_match"]._options = None
_APPLICATION.fields_by_name["job_title_snippet"]._options = None
_APPLICATION._options = None
# @@protoc_insertion_point(module_scope)
